@@ -51,6 +51,8 @@ VIF_DETAILS_MACVTAP_SOURCE = 'macvtap_source'
 VIF_DETAILS_MACVTAP_MODE = 'macvtap_mode'
 VIF_DETAILS_PHYSICAL_INTERFACE = 'physical_interface'
 VIF_DETAILS_BRIDGE_NAME = 'bridge_name'
+VIF_DETAILS_CONNECTIVITY = 'connectivity'
+VIF_DETAILS_BOUND_DRIVERS = 'bound_drivers'
 
 # OVS bridge datapath type: String value used to define if the bridge uses
 # kernel or userspace datapath.
@@ -103,6 +105,8 @@ VIF_TYPE_AGILIO_OVS = 'agilio_ovs'
 VIF_TYPE_HW_VEB = 'hw_veb'
 VIF_TYPE_HOSTDEV_PHY = 'hostdev_physical'
 
+VIF_UNPLUGGED_TYPES = (VIF_TYPE_BINDING_FAILED, VIF_TYPE_UNBOUND)
+
 # VNIC_TYPE: It's used to determine which mechanism driver to use to bind a
 #            port. It can be specified via the Neutron API. Default is normal,
 #            used by OVS and LinuxBridge agent.
@@ -112,10 +116,22 @@ VNIC_MACVTAP = 'macvtap'
 VNIC_BAREMETAL = 'baremetal'
 VNIC_DIRECT_PHYSICAL = 'direct-physical'
 VNIC_VIRTIO_FORWARDER = 'virtio-forwarder'
+VNIC_SMARTNIC = 'smart-nic'
+# - vdpa:  The vHost-vdpa transport is a new vHost backend type introduced
+#          in qemu 5.1. vHost-vdpa leverages the vdpa framework introduced in
+#          kernel 5.7 to implement  a vhost offload of a standard virtio-net
+#          interface to a software or hardware backend.
+VNIC_VHOST_VDPA = 'vdpa'
 
 VNIC_TYPES = [VNIC_NORMAL, VNIC_DIRECT, VNIC_MACVTAP, VNIC_BAREMETAL,
-              VNIC_DIRECT_PHYSICAL, VNIC_VIRTIO_FORWARDER]
+              VNIC_DIRECT_PHYSICAL, VNIC_VIRTIO_FORWARDER, VNIC_SMARTNIC,
+              VNIC_VHOST_VDPA]
 
+# VIF_DETAILS_CONNECTIVITY: Indicates what kind of connectivity the network
+#                           back-end provides: L2, L3 or not specified.
+CONNECTIVITY_L2 = 'l2'
+CONNECTIVITY_L3 = 'l3'
+CONNECTIVITY_LEGACY = 'legacy'
 
 # The alias of the extension.
 ALIAS = 'binding'
