@@ -59,6 +59,7 @@ DEVICE_OWNER_AGENT_GW = (DEVICE_OWNER_NETWORK_PREFIX +
                          "floatingip_agent_gateway")
 DEVICE_OWNER_ROUTER_SNAT = (DEVICE_OWNER_NETWORK_PREFIX +
                             "router_centralized_snat")
+DEVICE_OWNER_ROUTED = (DEVICE_OWNER_NETWORK_PREFIX + "routed")
 # TODO(johnsom) Remove after these stop being used. Neutron-LBaaS is now
 #               retired (train) and these should no longer be necessary.
 DEVICE_OWNER_LOADBALANCER = DEVICE_OWNER_NEUTRON_PREFIX + "LOADBALANCER"
@@ -94,7 +95,8 @@ IP_VERSION_6 = 6
 IPv4_BITS = 32
 IPv6_BITS = 128
 
-INVALID_MAC_ADDRESSES = ['00:00:00:00:00:00', 'FF:FF:FF:FF:FF:FF']
+BROADCAST_MAC = 'FF:FF:FF:FF:FF:FF'
+INVALID_MAC_ADDRESSES = ['00:00:00:00:00:00', BROADCAST_MAC]
 
 IPv4_ANY = '0.0.0.0/0'
 IPv6_ANY = '::/0'
@@ -606,7 +608,23 @@ ACCEPT_RA_WITH_FORWARDING = 2
 PRIVATE_CIDR_RANGE = '169.254.0.0/16'
 DVR_FIP_LL_CIDR = '169.254.64.0/18'
 L3_HA_NET_CIDR = '169.254.192.0/18'
-METADATA_CIDR = '169.254.169.254/32'
+
+# Well-known addresses of the metadata service.
+# When binding to an address, used with a port.
+METADATA_V4_IP = '169.254.169.254'
+# When configuring an address on an interface.
+# When adding a route.
+METADATA_V4_CIDR = '169.254.169.254/32'
+# When checking if a metadata subnet is present.
+METADATA_V4_SUBNET = '169.254.0.0/16'
+
+METADATA_V6_IP = 'fe80::a9fe:a9fe'
+METADATA_V6_CIDR = 'fe80::a9fe:a9fe/64'
+
+METADATA_PORT = 80
+
+# For backwards compatibility, prefer METADATA_V4_CIDR instead.
+METADATA_CIDR = METADATA_V4_CIDR
 
 # The only defined IpamAllocation status at this stage is 'ALLOCATED'.
 # More states will be available in the future - e.g.: RECYCLABLE
@@ -641,3 +659,10 @@ EXT_PARENT_PREFIX = 'ext_parent'
 
 RP_BANDWIDTHS = 'resource_provider_bandwidths'
 RP_INVENTORY_DEFAULTS = 'resource_provider_inventory_defaults'
+
+# Port NUMA affinity policies, matching Nova NUMA affinity policy constants
+PORT_NUMA_POLICY_REQUIRED = 'required'
+PORT_NUMA_POLICY_PREFERRED = 'preferred'
+PORT_NUMA_POLICY_LEGACY = 'legacy'
+PORT_NUMA_POLICIES = (PORT_NUMA_POLICY_REQUIRED, PORT_NUMA_POLICY_PREFERRED,
+                      PORT_NUMA_POLICY_LEGACY)
