@@ -12,7 +12,7 @@
 
 import contextlib
 import copy
-import inspect
+import functools
 import weakref
 
 from oslo_concurrency import lockutils
@@ -25,7 +25,6 @@ from oslo_utils import excutils
 from osprofiler import opts as profiler_opts
 import osprofiler.sqlalchemy
 from pecan import util as p_util
-import six
 import sqlalchemy
 from sqlalchemy import event  # noqa
 from sqlalchemy import exc as sql_exc
@@ -39,7 +38,6 @@ from neutron_lib.objects import exceptions as obj_exc
 
 
 MAX_RETRIES = 20
-OSPROFILER_TRACE_NAMES = {'neutron.db', 'neutron_lib.db'}
 LOG = logging.getLogger(__name__)
 _synchronized = lockutils.synchronized_with_prefix("neutron-")
 _CTX_MANAGER = None
@@ -69,9 +67,8 @@ def get_context_manager():
 def _set_hook(engine):
     if (profiler_opts.is_trace_enabled() and
             profiler_opts.is_db_trace_enabled()):
-        for trace_name in OSPROFILER_TRACE_NAMES:
-            osprofiler.sqlalchemy.add_tracing(
-                sqlalchemy, engine, trace_name)
+        osprofiler.sqlalchemy.add_tracing(
+            sqlalchemy, engine, "neutron.db")
 
 
 # TODO(ihrachys) the hook assumes options defined by osprofiler, and the only
@@ -132,7 +129,7 @@ def _tag_retriables_as_unretriable(f):
     This decorator can be used outside of a retry decorator to prevent
     decorators higher up from retrying again.
     """
-    @six.wraps(f)
+    @functools.wraps(f)
     def wrapped(*args, **kwargs):
         try:
             return f(*args, **kwargs)
@@ -148,25 +145,13 @@ def _copy_if_lds(item):
     return copy.deepcopy(item) if isinstance(item, (list, dict, set)) else item
 
 
-# Do retries with some randomness in the backoff, if the version
-# of oslo.db supports it.
-# TODO(dougwig): remove this gross if/else when lower constraints
-# on oslo.db is >= 4.37.0.
-if 'jitter' in inspect.getargspec(oslo_db_api.wrap_db_retry.__init__).args:
-    _retry_db_errors = oslo_db_api.wrap_db_retry(
-        max_retries=MAX_RETRIES,
-        retry_interval=0.5,
-        inc_retry_interval=True,
-        exception_checker=is_retriable,
-        jitter=True
-    )
-else:
-    _retry_db_errors = oslo_db_api.wrap_db_retry(
-        max_retries=MAX_RETRIES,
-        retry_interval=0.5,
-        inc_retry_interval=True,
-        exception_checker=is_retriable,
-    )
+_retry_db_errors = oslo_db_api.wrap_db_retry(
+    max_retries=MAX_RETRIES,
+    retry_interval=0.5,
+    inc_retry_interval=True,
+    exception_checker=is_retriable,
+    jitter=True
+)
 
 
 def retry_db_errors(f):
@@ -184,7 +169,7 @@ def retry_db_errors(f):
 
     @_tag_retriables_as_unretriable
     @_retry_db_errors
-    @six.wraps(f)
+    @functools.wraps(f)
     def wrapped(*args, **kwargs):
         try:
             # copy mutable args and kwargs to make retries safe. this doesn't
@@ -231,18 +216,17 @@ def retry_if_session_inactive(context_var_name='context'):
             # deals with the horrors of finding args of already decorated
             # functions
             ctx_arg_index = p_util.getargspec(f).args.index(context_var_name)
-        except ValueError:
+        except ValueError as e:
             msg = _("Could not find position of var %s") % context_var_name
-            raise RuntimeError(msg)
+            raise RuntimeError(msg) from e
         f_with_retry = retry_db_errors(f)
 
-        @six.wraps(f)
+        @functools.wraps(f)
         def wrapped(*args, **kwargs):
             # only use retry wrapper if we aren't nested in an active
             # transaction
-            if context_var_name in kwargs:
-                context = kwargs[context_var_name]
-            else:
+            context = kwargs.get(context_var_name)
+            if context is None:
                 context = args[ctx_arg_index]
             method = f if context.session.is_active else f_with_retry
             return method(*args, **kwargs)
